Add all granularity levels for all manually downloaded files. Here the structure is important. The the order for types should be similar to the order in files. OBS! The 6 digits from grunnkrets does not represent bydel.

geo_cast(
  files,
  type = NULL,
  year = NULL,
  keep.col = c("code", "name"),
  folder.path = NULL
)

Arguments

files

Files names with complete path to the files

type

Types equivalent to the file names. Must be the same order with file names

year

Year of the selected code list

keep.col

Existing column names to be kept

folder.path

Folder path to the files

Examples

if (FALSE) { files <- c( "C:/Geo/fylke/fylke2020.csv", "C:/Geo/kommune/kommune2020.csv", "C:/folder2/bydel2020.csv" ) types <- c("fylke", "kommune", "bydel") DT <- geo_cast(files = files, type = types, year = 2020) }