Create a table with all geo change and year. The files for the argument must be the output object from geo_set() function.

geo_merge(files, output = c("all", "split", "merge", "change", "complete"))

Arguments

files

A list of objects to be merged. The order must be from lowest to highest year.

output

Data output which can be one of these:

  • all : Dataset for all data. This is the default output

  • change : Dataset that include only codes that have changed

  • split : Dataset for codes that have been divided to at least two newer codes

  • merge : Dataset for at least two codes that are been merged into one

  • complete : A list of all different outputs

Examples

if (FALSE) { DT <- geo_merge(list(kommune2018, kommune2019, kommune2020)) dts <- geo_merge(list(kommune2018, kommune2019, kommune2020), output = "split") }