Read all CSV files in the folder specified if you prefer not to use apply family. The objects can be available in the raw if argument raw = TRUE. Important! Any existing objects of similar names will be replaced without warning. The object name will be something like "raw$kommune200825_01" if granularity type is kommune specified in the type argument.

read_csv(
  folder.path,
  type = NULL,
  sep = c(NA, ";", ","),
  encoding = NULL,
  raw = FALSE
)

Arguments

folder.path

Folder path to the files

type

Type of regional granularity ie. fylke, kommune etc.

sep

The separate symbols in the CSV files ie. ; or ,. If you leave it blank then appropriate symbols will be selected automatically. But if you should specify encoding type then, you have to choose the right sep for the file.

encoding

Select the suitable encoding

raw

If TRUE the objects will be available in raw environment