Create a table with all geo change and year. The files for the argument must be
the output object from geo_set() function.
geo_merge(files, output = c("all", "split", "merge", "change", "complete"))
| files | A list of objects to be merged. The order must be from lowest to highest year. |
|---|---|
| output | Data output which can be one of these:
|